==> nextcloud-22.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/zh_HK.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "是否要加入來自 {owner}@{remote} 的遠端分享 {name} ？",
    "Remote share" : "遠端分享",
    "Remote share password" : "遠端分享密碼",
    "Cancel" : "取消",
    "Add remote share" : "添加遠端分享",
    "Copy" : "複製",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按 ⌘-C 來複製",
    "Press Ctrl-C to copy." : "請按 Ctrl-C 來複製",
    "Invalid Federated Cloud ID" : "雲端聯盟 ID 不正確",
    "Server to server sharing is not enabled on this server" : "此伺服器未啟用伺服器到伺服器分享功能",
    "Couldn't establish a federated share." : "無法建立聯盟式分享",
    "Couldn't establish a federated share, maybe the password was wrong." : "無法建立聯盟式分享，可能是密碼錯誤。",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "聯合雲分享 請求發送成功！您將收到邀請。注意您的通知提醒。",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "無法建立聯合雲分享 ，可能是要聯合的伺服器版本太舊（Nextcloud <= 9）。",
    "It is not allowed to send federated group shares from this server." : "不允許從此伺服器發送聯盟式群組分享 。",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "分享 %1$s 失敗，此項目已經與用戶 %2$s 分享",
    "Not allowed to create a federated share with the same user" : "不允許與同一個用戶建立聯盟式分享",
    "Federated shares require read permissions" : "聯合分享需要讀取權限",
    "File is already shared with %s" : "檔案已和 %s 分享",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1$s 分享失敗，無法找到 %2$s，可能該伺服器當前無法訪問或者使用了自簽名證書。",
    "Could not find share" : "沒有發現分享 ",
    "Federated sharing" : "聯盟式分享",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "您收到了來自%4$s（%1$s）的作為遠程分享 的\"%3$s\"（代表%5$s（%2$s））",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "您得到 {share} 是從 {user} 的遠程分享（代替 {behalf}）",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "您收到了來自%4$s（%1$s）作為遠程分享的\"%3$s\"",
    "You received {share} as a remote share from {user}" : "您從 {user} 收到了遠端分享 {share}",
    "Accept" : "接受",
    "Decline" : "拒絕",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "可透過我的 #Nextcloud 聯盟雲端 ID 與我分享，請看 %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "可透過我的 #Nextcloud 聯盟雲端 ID 與我分享",
    "Sharing" : "分享 ",
    "Federated file sharing" : "聯盟式檔案分享",
    "Provide federated file sharing across servers" : "在伺服器間提供聯盟式檔案分享 ",
    "Federated Cloud Sharing" : "聯盟式雲端分享",
    "Open documentation" : "開啟說明文件",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "配置人們如何在伺服器之間共享。 這也包括此伺服器上用戶之間的共享，如果他們使用聯合共享。",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "允許此伺服器上的用戶將分享發送到其他伺服器（此選項還允許 WebDAV 訪問公共分享 ）",
    "Allow users on this server to receive shares from other servers" : "允許用戶從其他伺服器接收分享 ",
    "Allow users on this server to send shares to groups on other servers" : "允許此伺服器上的用戶向其他伺服器上的群組發送分享 ",
    "Allow users on this server to receive group shares from other servers" : "允許此伺服器上的用戶接收其他伺服器的群組分享",
    "Search global and public address book for users" : "在全局和公共通訊錄中尋找用戶",
    "Allow users to publish their data to a global and public address book" : "允許用戶將其數據發佈到全球和公共通訊錄",
    "Federated Cloud" : "聯盟式雲端",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "您可以與使用 Nextcloud 伺服器或其他 Open Cloud Mesh（OCM）兼容伺服器和服務的任何人分享！只需將他們的聯盟式雲端 ID 放在分享對話框中。聯盟式雲端 ID 的格式為 person@cloud.example.com ",
    "Your Federated Cloud ID:" : "您的雲端聯盟 ID：",
    "Share it so your friends can share files with you:" : "使用分享以便您的朋友可以與您分享檔案：",
    "Add to your website" : "新增至您的網站",
    "Share with me via Nextcloud" : "透過 Nextcloud 與我分享",
    "HTML Code:" : "HTML 代碼：",
    "Adjust how people can share between servers." : "調整人們如何在伺服器之間分享。"
},
"nplurals=1; plural=0;");

==> nextcloud-30.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/zh_HK.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "雲端聯盟 ID 不正確",
    "Server to server sharing is not enabled on this server" : "此伺服器未啟用伺服器到伺服器分享功能",
    "Couldn't establish a federated share." : "無法建立聯盟式分享",
    "Couldn't establish a federated share, maybe the password was wrong." : "無法建立聯盟式分享，可能是密碼錯誤。",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "聯合雲分享 請求發送成功！您將收到邀請。注意您的通知提醒。",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "無法建立聯合雲分享 ，可能是要聯合的伺服器版本太舊（Nextcloud <= 9）。",
    "It is not allowed to send federated group shares from this server." : "不允許從此伺服器發送聯盟式群組分享 。",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "分享 %1$s 失敗，因為此項目已與帳戶 %2$s 分享",
    "Not allowed to create a federated share to the same account" : "不允許與同一個帳戶建立聯邦分享",
    "Federated shares require read permissions" : "聯合分享需要讀取權限",
    "File is already shared with %s" : "檔案已和 %s 分享",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1$s 分享失敗，無法找到 %2$s，可能該伺服器當前無法訪問或者使用了自簽名證書。",
    "Could not find share" : "沒有發現分享 ",
    "Federated sharing" : "聯盟式分享",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "您得到 {share} 是從 {user} 的遠程分享（代替 {behalf}）",
    "You received {share} as a remote share from {user}" : "您從 {user} 收到了遠端分享 {share}",
    "Accept" : "接受",
    "Decline" : "拒絕",
    "Federated Cloud Sharing" : "聯盟式雲端分享",
    "Sharing" : "分享 ",
    "Federated file sharing" : "聯盟式檔案分享",
    "Provide federated file sharing across servers" : "在伺服器間提供聯盟式檔案分享 ",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "配置人們如何在伺服器之間共享。 這也包括此伺服器上人仕之間的共享，如果他們使用聯合共享。",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "允許此伺服器上的人仕將分享發送到其他伺服器（此選項還允許 WebDAV 訪問公共分享 ）",
    "Allow people on this server to receive shares from other servers" : "允許此伺服器上的人仕接收來自其他伺服器的分享",
    "Allow people on this server to send shares to groups on other servers" : "允許此伺服器上的人仕傳送分享在其他伺服器上的群組",
    "Allow people on this server to receive group shares from other servers" : "允許此伺服器上的人仕接收來自其他伺服器的群組分享",
    "Search global and public address book for people" : "搜尋全面的與公開通訊錄中的人仕",
    "Allow people to publish their data to a global and public address book" : "允許人仕將其資料發佈到整體的且公開的通訊錄",
    "Unable to update federated files sharing config" : "無法更新聯合檔案分享配置",
    "Federated Cloud" : "聯盟式雲端",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "您可以與使用 Nextcloud 伺服器或其他 Open Cloud Mesh（OCM）兼容伺服器和服務的任何人分享！只需將他們的聯盟式雲端 ID 放在分享對話框中。聯盟式雲端 ID 的格式為 person@cloud.example.com ",
    "Your Federated Cloud ID:" : "您的雲端聯盟 ID：",
    "Share it so your friends can share files with you:" : "使用分享以便您的朋友可以與您分享檔案：",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X（前身為 Twitter）",
    "formerly Twitter" : "前身為 Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "新增至您的網站",
    "Share with me via Nextcloud" : "透過 Nextcloud 與我分享",
    "HTML Code:" : "HTML 代碼：",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "可透過我的 #Nextcloud 聯盟雲端 ID 與我分享，請見 {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "可透過我的 #Nextcloud 聯盟雲端 ID 與我分享",
    "Cloud ID copied to the clipboard" : "已複製 Cloud ID 至剪貼板",
    "Copy to clipboard" : "複製到剪貼板",
    "Clipboard not available. Please copy the cloud ID manually." : "剪貼板不可用。請人手複製 cloud ID。",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "是否要加入來自 {owner}@{remote} 的遠端分享 {name} ？",
    "Remote share" : "遠端分享",
    "Remote share password" : "遠端分享密碼",
    "Cancel" : "取消",
    "Add remote share" : "添加遠端分享",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "分享 %1$s 失敗，此項目已經與用戶 %2$s 分享",
    "Not allowed to create a federated share with the same user" : "不允許與同一個用戶建立聯盟式分享",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "配置人們如何在伺服器之間共享。 這也包括此伺服器上用戶之間的共享，如果他們使用聯合共享。",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "允許此伺服器上的用戶將分享發送到其他伺服器（此選項還允許 WebDAV 訪問公共分享 ）",
    "Allow users on this server to receive shares from other servers" : "允許用戶從其他伺服器接收分享 ",
    "Allow users on this server to send shares to groups on other servers" : "允許此伺服器上的用戶向其他伺服器上的群組發送分享 ",
    "Allow users on this server to receive group shares from other servers" : "允許此伺服器上的用戶接收其他伺服器的群組分享",
    "Search global and public address book for users" : "在全局和公共通訊錄中尋找用戶",
    "Allow users to publish their data to a global and public address book" : "允許用戶將其數據發佈到全球和公共通訊錄",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Clipboard is not available" : "剪貼板不可用",
    "Copied!" : "已複製！"
},
"nplurals=1; plural=0;");
